@@ -1064,7 +1064,7 @@ void PlayList::add(const TQStringList& urlList, TQListViewItem* after)
 						emit signalRequestForAudioCD(mediadevice);
 						return;
 					}
-					if (properties[10] == "media/dvdvideo")
+					if (properties[10] == "media/dvdvideo" || properties[10] == "media/blurayvideo")
 					{
 						mediadevice = properties[5];
 						delete progress;
